from fastapi import APIRouter, Depends, HTTPException, status
from sqlalchemy.orm import Session
from typing import List

from app.db.session import get_db
from app.schemas.result import ResultCreate, ResultResponse
from app.services.result import create_result, get_result, get_results, get_user_results

router = APIRouter()

@router.post("/", response_model=ResultResponse, status_code=status.HTTP_201_CREATED)
def create_result_endpoint(result_data: ResultCreate, db: Session = Depends(get_db)):
    """Create a new quiz result"""
    return create_result(db=db, result_data=result_data)

@router.get("/{result_id}", response_model=ResultResponse)
def get_result_endpoint(result_id: int, db: Session = Depends(get_db)):
    """Get a specific result by ID"""
    db_result = get_result(db=db, result_id=result_id)
    if db_result is None:
        raise HTTPException(status_code=404, detail="Result not found")
    return db_result

@router.get("/", response_model=List[ResultResponse])
def get_results_endpoint(skip: int = 0, limit: int = 100, db: Session = Depends(get_db)):
    """Get all results"""
    return get_results(db=db, skip=skip, limit=limit)

@router.get("/user/{user_id}", response_model=List[ResultResponse])
def get_user_results_endpoint(user_id: str, db: Session = Depends(get_db)):
    """Get all results for a specific user"""
    return get_user_results(db=db, user_id=user_id)